if [ ! -L dev/cdrom ]; then # provide a reasonable default
 ( cd dev ; ln -sf /dev/scd0 cdrom )
fi
( cd dev ; rm -rf modem )
( cd dev ; ln -sf  cua1 modem )
( cd dev ; rm -rf mouse )
( cd dev ; ln -sf  cua0 mouse )
( cd dev ; rm -rf core )
( cd dev ; ln -sf /proc/kcore core )
( cd dev ; rm -rf ftape )
( cd dev ; ln -sf rft0 ftape )
( cd dev ; rm -rf nftape )
( cd dev ; ln -sf nrft0 nftape )
( cd dev ; rm -rf XOR )
( cd dev ; ln -sf null XOR )
( cd dev ; rm -rf rmt0 )
( cd dev ; ln -sf st0 rmt0 )
( cd dev ; rm -rf rmt1 )
( cd dev ; ln -sf st1 rmt1 )
( cd dev ; rm -rf nrmt0 )
( cd dev ; ln -sf nst0 nrmt0 )
( cd dev ; rm -rf nrmt1 )
( cd dev ; ln -sf nst1 nrmt1 )
( cd dev ; rm -rf fd0H360 )
( cd dev ; ln -sf fd0D360 fd0H360 )
( cd dev ; rm -rf fd0H720 )
( cd dev ; ln -sf fd0D720 fd0H720 )
( cd dev ; rm -rf fd1H360 )
( cd dev ; ln -sf fd1D360 fd1H360 )
( cd dev ; rm -rf fd1H720 )
( cd dev ; ln -sf fd1D720 fd1H720 )
( cd dev ; rm -rf nfsd )
( cd dev ; ln -sf socksys nfsd )
( cd dev ; rm -rf systty )
( cd dev ; ln -sf console systty )
